@@ -16,39 +16,30 @@ from mo_logs.log_usingNothing import StructuredLogger
 from mo_threads import Queue, THREAD_STOP, Thread, Till
 
 DEBUG = False
+PERIOD = 0.3
 
 
 class StructuredLogger_usingThread(StructuredLogger):
-
-    def __init__(self, logger):
+    def __init__(self, logger, period=PERIOD):
         if not isinstance(logger, StructuredLogger):
             Log.error("Expecting a StructuredLogger")
 
-        self.queue = Queue("Queue for " + self.__class__.__name__, max=10000, silent=True, allow_add_after_close=True)
         self.logger = logger
-
-        def worker(logger, please_stop):
-            try:
-                while True:
-                    logs = self.queue.pop_all()
-                    if not logs:
-                        if please_stop:
-                            break
-                        (Till(seconds=1) | please_stop).wait()
-                        continue
-                    for log in logs:
-                        if log is THREAD_STOP:
-                            please_stop.go()
-                        else:
-                            logger.write(**log)
-            except Exception as e:
-                print("problem in " + StructuredLogger_usingThread.__name__ + ": " + str(e))
-            finally:
-                Log.note("stop the child")
-                logger.stop()
-
-        self.thread = Thread("Thread for " + self.__class__.__name__, worker, logger)
-        self.thread.parent.remove_child(self.thread)  # LOGGING WILL BE RESPONSIBLE FOR THREAD stop()
+        self.queue = Queue(
+            "Queue for " + self.__class__.__name__,
+            max=10000,
+            silent=True,
+            allow_add_after_close=True,
+        )
+        self.thread = Thread(
+            "Thread for " + self.__class__.__name__,
+            worker,
+            logger,
+            self.queue,
+            period
+        )
+        # worker WILL BE RESPONSIBLE FOR THREAD stop()
+        self.thread.parent.remove_child(self.thread)
         self.thread.start()
 
     def write(self, template, params):
@@ -70,3 +61,23 @@ class StructuredLogger_usingThread(StructuredLogger):
         with suppress_exception:
             self.queue.close()
 
+
+def worker(logger, queue, period, please_stop):
+    try:
+        while True:
+            log = queue.pop(till=please_stop)
+            if not log:
+                break
+            logs = [log] + queue.pop_all()
+            for log in logs:
+                if log is THREAD_STOP:
+                    please_stop.go()
+                else:
+                    logger.write(**log)
+            (Till(seconds=period) | please_stop).wait()
+    except Exception as e:
+        import sys
+        sys.stderr.write("problem in " + StructuredLogger_usingThread.__name__ + ": " + str(e))
+    finally:
+        Log.note("stop the child")
+        logger.stop()
